@@ -244,7 +244,9 @@ class OpenRazerBackend(Backend):
 
         workarounds = self._get_workaround_options(rdevice)
         if workarounds:
-            main_zone.options = workarounds
+            # Remove existing EffectOption(s) from main zone
+            main_zone.options = [option for option in main_zone.options if not isinstance(option, Backend.EffectOption)]
+            main_zone.options += workarounds
 
         # Add other "main" options
         if rdevice.has("available_dpi"):
@@ -744,6 +746,9 @@ class OpenRazerBackend(Backend):
         has_starlight_single = self._has_zone_capability(rdevice, zone, "starlight_single")
         has_starlight_dual = self._has_zone_capability(rdevice, zone, "starlight_dual")
 
+        openrazer_version_major = int(self.version.split(".")[0])
+        openrazer_version_minor = int(self.version.split(".")[1])
+
         if self._has_zone_capability(rdevice, zone, "none"):
             class NoneOption(Backend.EffectOption):
                 def __init__(self, rzone, persistence):
@@ -764,6 +769,10 @@ class OpenRazerBackend(Backend):
             option.icon = self.get_icon("params", "0")
             options.append(option)
 
+            # Basilisk V3 firmware becomes buggy when None effect is set. Removed in OpenRazer 3.8.0. (openrazer/openrazer#2156)
+            if rdevice.name == "Razer Basilisk V3" and (openrazer_version_major <= 3 and openrazer_version_minor <= 7):
+                options.pop()
+
         if self._has_zone_capability(rdevice, zone, "on"):
             class OnOption(Backend.EffectOption):
                 def __init__(self, rzone, persistence):
