@@ -69,6 +69,7 @@ class MenuBar(PolychromaticBase):
         self._bind_item("actionWebsite", self.polychromatic_website)
         self._bind_item("actionReleaseNotes", self.polychromatic_release_notes)
         self._bind_item("actionReportBug", self.polychromatic_report_bug)
+        self._bind_item("actionTranslate", self.polychromatic_translate)
         self._bind_item("actionDonate", self.polychromatic_donate)
         self._bind_item("actionAbout", self.about_polychromatic)
 
@@ -232,6 +233,10 @@ class MenuBar(PolychromaticBase):
         self._prompt_on_locale_change(self._("Report Bug"))
         webbrowser.open("https://polychromatic.app/permalink/bugs/")
 
+    def polychromatic_translate(self):
+        self._prompt_on_locale_change(self._("Translate"))
+        webbrowser.open("https://docs.polychromatic.app/translations/")
+
     def polychromatic_donate(self):
         self._prompt_on_locale_change(self._("Donate"))
         webbrowser.open("https://polychromatic.app/permalink/donate/")
@@ -303,7 +308,7 @@ class MenuBar(PolychromaticBase):
 
         # Show license text
         license = about.findChild(QTextEdit, "LicenseText")
-        license.setPlainText(license_text)
+        license.setMarkdown(license_text)
 
         # Set up the about window
         close = about.findChild(QPushButton, "Close")
@@ -323,14 +328,15 @@ class MenuBar(PolychromaticBase):
     def about_polychromatic(self):
         logo = common.get_icon("logo", "polychromatic")
 
-        with open(os.path.join(self.appdata.paths.data_dir, "licenses/app.txt"), "r") as f:
+        with open(os.path.join(self.appdata.paths.data_dir, "licenses/app.md"), "r") as f:
             license = f.read()
 
         links = [
             [self._("Documentation"), "https://docs.polychromatic.app/"],
             [self._("Source Code"), "https://polychromatic.app/permalink/src/"],
             [self._("Release Notes"), "https://polychromatic.app/permalink/latest/"],
-            [self._("Donate"), "https://polychromatic.app/permalink/donate/"]
+            [self._("Translate"), "https://docs.polychromatic.app/translations/"],
+            [self._("Donate"), "https://polychromatic.app/permalink/donate/"],
         ]
 
         versions = self.appdata.versions
