@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
 #
 # Shortcut to test a handful of different kinds of OpenRazer devices
 #
@@ -6,7 +6,7 @@
 export HOME=/tmp
 
 # Verify path exists
-if [ ! -d "$OPENRAZER_SRC" ]; then
+if [[ ! -d "${OPENRAZER_SRC}" ]]; then
     echo "Please set the OPENRAZER_SRC environment variable to the OpenRazer source code:"
     echo -e "\n  export OPENRAZER_SRC=/path/to/repo\n"
     exit 1
@@ -19,10 +19,10 @@ config_dir="/tmp/daemon_config/"
 test_dir="/tmp/daemon_test"
 devices="razerabyssus1800 razerbasilisk razerblackwidowstealth razerblackwidowxchroma razerblade152019advanced razerbladelate2016 razercore razerfireflyv2 razerhuntsmanelite razerkraken7.1chroma razerkrakenkittyedition razernagahex razernommochroma razerorbweaver razerviper"
 
-cd "$OPENRAZER_SRC"
+cd "${OPENRAZER_SRC}"
 openrazer-daemon -s
 
-./scripts/create_fake_device.py --dest "$test_dir" --non-interactive $devices &
+./scripts/create_fake_device.py --dest "${test_dir}" --non-interactive ${devices} &
 sleep 1
 
-./daemon/run_openrazer_daemon.py --verbose -F --run-dir "$config_dir/data" --log-dir "$config_dir/logs" --test-dir "$test_dir"
+./daemon/run_openrazer_daemon.py --verbose -F --run-dir "${config_dir}/data" --log-dir "${config_dir}/logs" --test-dir "${test_dir}"
